@@ -7,7 +7,7 @@ import requests
 
 
 class Canadapost(Base):
-    provider = 'CanadaPost'
+    provider = 'canadapost'
     api = 'Addres Complete API'
     url = 'https://ws1.postescanada-canadapost.ca/AddressComplete'
     url += '/Interactive/RetrieveFormatted/v2.00/json3ex.ws'
@@ -36,7 +36,6 @@ class Canadapost(Base):
         if bool(self.key and self.id):
             self._connect()
             self._parse(self.content)
-            self._test()
             self._json()
 
     def __repr__(self):
@@ -89,6 +88,22 @@ class Canadapost(Base):
                 self.id = items['Id']
                 return self.id
 
+    @property
+    def lng(self):
+        return 0.0
+
+    @property
+    def lat(self):
+        return 0.0
+
+    @property
+    def wkt(self):
+        return str('')
+
+    @property
+    def geometry(self):
+        return dict()
+
     @property
     def ok(self):
         return bool(self.postal)
